@@ -1,5 +1,5 @@
 import asyncio
-from trinsic.trinsic_util import set_event_loop_policy
+from trinsic.trinsic_util import set_eventloop_policy
 
 from trinsic.proto.services.provider.v1 import GetOberonKeyRequest
 from trinsic.provider_service import ProviderService
@@ -14,5 +14,5 @@ async def demo():
 
 
 if __name__ == "__main__":
-    set_event_loop_policy()
+    set_eventloop_policy()
     asyncio.run(demo())
